@@ -38,12 +38,12 @@ from typing import (
     Union,
     cast,
 )
-from typing_extensions import TypeAlias
 
-import requests
+import aiohttp.client_exceptions
 from pygls.lsp.types import Location, Position, Range
 from pygls.server import LanguageServer
 from pygls.workspace import Document
+from typing_extensions import TypeAlias
 from zc.buildout.buildout import _buildout_default_options
 from zc.buildout.configparser import (
     MissingSectionHeaderError,
@@ -53,10 +53,9 @@ from zc.buildout.configparser import (
     section_header,
 )
 
-from . import jinja, recipes
+from . import aiohttp_session, jinja, recipes
 
 logger = logging.getLogger(__name__)
-requests_session = requests.Session()
 
 # Matches a reference like ${section:option}
 # We also tolerate ${section: without option or the ending } to generate completions.
@@ -178,6 +177,7 @@ class BuildoutOptionDefinition:
     copied = BuildoutOptionDefinition(self.value, self.locations[0])
     copied.locations = self.locations
     copied.values = self.values
+    copied.default_values = self.default_values
     return copied
 
 
@@ -506,6 +506,7 @@ class BuildoutProfile(Dict[str, BuildoutSection], BuildoutTemplate):
     copied = self.__class__(self.uri, self.source)
     copied.section_header_locations = self.section_header_locations.copy()
     copied.has_dynamic_extends = self.has_dynamic_extends
+    copied.has_jinja = self.has_jinja
     for k, v in self.items():
       copied[k] = v.copy()
     return copied
@@ -525,6 +526,10 @@ class BuildoutProfile(Dict[str, BuildoutSection], BuildoutTemplate):
     """Flag true if this resolved buildout had extends defined dynamically.
     This only happens with SlapOS instance buildout which are templates of profiles.
     """
+    self.has_jinja = False
+    """Flag true if this resolved buildout is a jinja template.
+    This only happens with SlapOS instance buildout which are templates of profiles.
+    """
 
   async def getTemplate(
       self,
@@ -954,8 +959,11 @@ async def parse(
       'https',
   ):
     try:
-      fp = io.StringIO(requests_session.get(uri).text)
-    except requests.exceptions.ConnectionError:
+      async with aiohttp_session.get_session().get(uri) as resp:
+        resp.raise_for_status()
+        fp = io.StringIO(await resp.text())
+    except aiohttp.client_exceptions.ClientError:
+      logger.warning('Error parsing from uri %s', uri, exc_info=True)
       fp = io.StringIO('')
   else:
     document = ls.workspace.get_document(uri)
@@ -1090,6 +1098,7 @@ async def _parse(
 
     jinja_parser.feed(line)
     if jinja_parser.is_in_jinja:
+      sections.has_jinja = True
       continue
     line = jinja_parser.line
 
@@ -1358,7 +1367,9 @@ async def _open(
   extends_option = profile['buildout'].pop(
       'extends', None) if 'buildout' in profile else None
 
+  result = profile
   has_dynamic_extends = False
+  has_jinja = profile.has_jinja
   if extends_option:
     extends = extends_option.value.split()
     has_dynamic_extends = (jinja.JinjaParser.jinja_value in extends) or any(
@@ -1375,6 +1386,7 @@ async def _open(
         eresult = await _open(ls, base, extends.pop(0), seen, allow_errors)
         for fname in extends:
           has_dynamic_extends = has_dynamic_extends or eresult.has_dynamic_extends
+          has_jinja = has_jinja or eresult.has_jinja
           eresult = _update(eresult, await _open(ls, base, fname, seen,
                                                  allow_errors))
         for absolute_extend in absolute_extends:
@@ -1382,10 +1394,7 @@ async def _open(
 
       if not has_dynamic_extends:
         _resolved_extends_cache[absolute_extends] = eresult
-
-    result = _update(eresult, profile)
-  else:
-    result = profile
+      result = _update(eresult, profile)
 
   seen.pop()
 
@@ -1403,6 +1412,7 @@ async def _open(
         pass
 
   result.has_dynamic_extends = has_dynamic_extends
+  result.has_jinja = has_jinja
   resolved = cast(ResolvedBuildout, result)
   _resolved_buildout_cache[uri] = resolved
   return resolved.copy()
