@@ -1,7 +1,9 @@
+import asyncio
 import logging
 import re
 import urllib.parse
-from typing import AsyncIterable, Set
+from typing import AsyncIterable, Awaitable, List, Optional, Set, Tuple
+import packaging
 
 from pygls.lsp.types import (
     Diagnostic,
@@ -76,7 +78,9 @@ async def getDiagnostics(
   has_dynamic_extends = (isinstance(resolved_buildout,
                                     buildout.BuildoutProfile)
                          and resolved_buildout.has_dynamic_extends)
-  if not has_dynamic_extends:
+  has_jinja = (isinstance(resolved_buildout, buildout.BuildoutProfile)
+               and resolved_buildout.has_jinja)
+  if not has_dynamic_extends and not has_jinja:
     installed_parts: Set[str] = set([])
     if isinstance(resolved_buildout, buildout.BuildoutProfile):
       if "parts" in resolved_buildout["buildout"]:
@@ -139,7 +143,8 @@ async def getDiagnostics(
                   severity=DiagnosticSeverity.Error,
               )
 
-        # check for options redefined to same values
+        # hints with redefined options, but at "Information" level when option redefines
+        # the same values
         for option_name, option in section.items():
           if option.locations[-1].uri != uri:
             continue
@@ -149,20 +154,25 @@ async def getDiagnostics(
           # per profile, so redefining an option from another profile with the same
           # ${:_profile_base_location_} should not be considered as redefining to
           # same value.
-          if len(option.locations) > 1 and (_profile_base_location_re.sub(
-              option.locations[-1].uri,
-              option.values[-1],
-          ) == _profile_base_location_re.sub(
-              option.locations[-2].uri,
-              option.values[-2],
-          )):
+          if len(option.locations) > 1:
+            is_same_value = (_profile_base_location_re.sub(
+                option.locations[-1].uri,
+                option.values[-1],
+            ) == _profile_base_location_re.sub(
+                option.locations[-2].uri,
+                option.values[-2],
+            ))
+
             related_information = []
             reported_related_location = set()
+            overriding_default_value = False
             for other_location, other_value, other_is_default_value in zip(
                 option.locations,
                 option.values,
                 option.default_values,
             ):
+              if other_is_default_value:
+                overriding_default_value = True
               hashable_location = (
                   other_location.uri,
                   other_location.range.start.line,
@@ -176,14 +186,23 @@ async def getDiagnostics(
                       message=f"default value: `{other_value}`"
                       if other_is_default_value else f"value: `{other_value}`",
                   ))
-
-            yield Diagnostic(
-                message=f"`{option_name}` already has value `{option.value}`.",
-                range=option.locations[-1].range,
-                source="buildout",
-                severity=DiagnosticSeverity.Warning,
-                related_information=related_information,
-            )
+            if is_same_value:
+              yield Diagnostic(
+                  message=
+                  f"`{option_name}` already has value `{option.value}`.",
+                  range=option.locations[-1].range,
+                  source="buildout",
+                  severity=DiagnosticSeverity.Information,
+                  related_information=related_information,
+              )
+            elif not overriding_default_value:
+              yield Diagnostic(
+                  message=f"`{option_name}` overrides an existing value.",
+                  range=option.locations[-1].range,
+                  source="buildout",
+                  severity=DiagnosticSeverity.Hint,
+                  related_information=related_information,
+              )
 
       jinja_parser = jinja.JinjaParser()
       if parsed is not None and "extends" in parsed["buildout"]:
@@ -234,6 +253,13 @@ async def getDiagnostics(
               )
 
       if resolved_buildout.get('versions'):
+        sem = asyncio.Semaphore(4)
+        package_version_options: List[Tuple[
+            str, str, buildout.BuildoutOptionDefinition]] = []
+        known_vulnerabilities_coros: List[Awaitable[Tuple[
+            types.KnownVulnerability, ...]]] = []
+        latest_version_coros: List[Awaitable[Optional[
+            packaging.version.Version]]] = []
         for package_name, option in resolved_buildout['versions'].items():
           if option.location.uri != uri:
             continue
@@ -257,19 +283,87 @@ async def getDiagnostics(
               package_version,
               option.location,
           )
-
-          known_vulnerabilities = tuple(
+          package_version_options.append(
+              (package_name, package_version, option))
+          known_vulnerabilities_coros.append(
               pypi_client.get_known_vulnerabilities(
                   package_name,
                   package_version,
+                  sem,
               ))
-          newer_version = pypi_client.get_latest_version(
-              package_name, package_version)
-          if newer_version:
+          latest_version_coros.append(
+              pypi_client.get_latest_version(
+                  package_name,
+                  package_version,
+                  sem,
+              ))
+        logger.debug('gathering %d known vulnerabilities',
+                     len(known_vulnerabilities_coros))
+        known_vulnerabilities_results = await asyncio.gather(
+            *known_vulnerabilities_coros, return_exceptions=True)
+        logger.debug('gathered %s', known_vulnerabilities_results)
+
+        logger.debug('gathering %d latest versions', len(latest_version_coros))
+        latest_version_results = await asyncio.gather(*latest_version_coros,
+                                                      return_exceptions=True)
+        logger.debug('gathered %s', latest_version_results)
+        for (
+            (package_name, package_version, option),
+            known_vulnerabilities,
+            latest_version,
+        ) in zip(
+            package_version_options,
+            known_vulnerabilities_results,
+            latest_version_results,
+        ):
+          if isinstance(latest_version, types.ProjectNotFound):
+            yield Diagnostic(
+                message=f'Project {package_name} does not exist',
+                range=option.location.range,
+                source="buildout",
+                severity=DiagnosticSeverity.Warning,
+                data=types.PyPIPackageInfo(
+                    latest_version='',
+                    url=pypi_client.get_home_page_url(
+                        package_name,
+                        package_version,
+                    ),
+                    known_vulnerabilities=[],
+                ),
+            )
+            continue
+          elif isinstance(known_vulnerabilities, types.VersionNotFound):
+            yield Diagnostic(
+                message=
+                f'Version {package_version} does not exist for {package_name}',
+                range=option.location.range,
+                source="buildout",
+                severity=DiagnosticSeverity.Warning,
+                data=types.PyPIPackageInfo(
+                    latest_version=str(latest_version),
+                    url=pypi_client.get_home_page_url(
+                        package_name,
+                        package_version,
+                    ),
+                    known_vulnerabilities=[],
+                ),
+            )
+            continue
+          elif isinstance(known_vulnerabilities, BaseException) or isinstance(
+              latest_version, BaseException):
+            logger.error(
+                'error with %s %s: %s / %s',
+                package_name,
+                package_version,
+                known_vulnerabilities,
+                latest_version,
+            )
+            continue
+          if latest_version:
             severity = DiagnosticSeverity.Hint
-            message = f"Newer version available ({newer_version})"
+            message = f"Newer version available ({latest_version})"
             if known_vulnerabilities:
-              message = f'{package_name} {package_version} has some known vunerabilities:\n' + '\n\n'.join(
+              message = f'{package_name} {package_version} has some known vulnerabilities:\n' + '\n\n'.join(
                   f"{v.id}\n{v.details}\n{v.link}"
                   for v in known_vulnerabilities)
               severity = DiagnosticSeverity.Warning
@@ -280,7 +374,7 @@ async def getDiagnostics(
                 source="buildout",
                 severity=severity,
                 data=types.PyPIPackageInfo(
-                    latest_version=str(newer_version),
+                    latest_version=str(latest_version),
                     url=pypi_client.get_home_page_url(
                         package_name,
                         package_version,
